@@ -380,6 +380,8 @@ trtAssign <- function(dtName, nTrt = 2, balanced = TRUE,
     dt[, `:=`(.stratum = NULL, .n = NULL)]
 
     if (nTrt == 2) dt[, grpExp := grpExp - 1]
+    dt[, grpExp := as.integer(grpExp)]
+    
     data.table::setnames(dt, "grpExp", grpName)
     data.table::setkeyv(dt, key(dtName))
   } else { # balanced is FALSE - strata are not relevant
@@ -394,13 +396,8 @@ trtAssign <- function(dtName, nTrt = 2, balanced = TRUE,
       formula <- round(ratio / sum(ratio), 8)
     }
 
-
     dt <- trtObserve(dt, formulas = formula, logit.link = FALSE, grpName)
   }
-  
-  for (i in seq_along(dt)) {
-    dt[[i]] <- as.integer(dt[[i]])
-  }
 
   return(dt[])
 }
