@@ -112,29 +112,41 @@ d <- list()
 d[[1]] <- data.table("beta", "mean", "both", "-", "dispersion", "X", "-", "X") 
 d[[2]] <- data.table("binary", "probability", "both", "-", "-", "X", "-", "X") 
 d[[3]] <- data.table("binomial", "probability", "both", "-", "# of trials", "X", "-", "X")
-d[[4]] <- data.table("categorical", "probability", "string", " p_1;p_2;...;p_n", "a;b;c", "X", "-", "-")
-d[[5]] <- data.table("exponential", "mean", "both", "-", "-", "X", "X", "-")
-d[[6]] <- data.table("gamma", "mean", "both", "-", "dispersion", "X", "X", "-")
-d[[7]] <- data.table("mixture", "formula", "string", "x_1 | p_1 + ... + x_n | p_n", "-", "X", "-", "-")
-d[[8]] <- data.table("negBinomial", "mean", "both", "-", "dispersion", "X", "X", "-")
-d[[9]] <- data.table("nonrandom", "formula", "both", "-", "-", "X", "-", "-")
-d[[10]] <- data.table("normal", "mean", "both", "-", "variance", "X", "-", "-")
-d[[11]] <- data.table("noZeroPoisson", "mean", "both", "-", "-", "X", "X", "-")
-d[[12]] <- data.table("poisson", "mean", "both", "-", "-", "X", "X", "-")
-d[[13]] <- data.table("trtAssign", "ratio", "string", "r_1;r_2;...;r_n", "stratification", "X", "X", "-")
-d[[14]] <- data.table("uniform", "range", "string", "from ; to", "-", "X", "-", "-")
-d[[15]] <- data.table("uniformInt", "range", "string", "from ; to", "-", "X", "-", "-")
+d[[4]] <- data.table("categorical", "probability", "string", "p_1;p_2;...;p_n", "a;b;c", "X", "-", "-")
+d[[5]] <- data.table("clusterSize", "total N", "both", "-", "dispersion", "X", "-", "-")
+d[[6]] <- data.table("exponential", "mean", "both", "-", "-", "X", "X", "-")
+d[[7]] <- data.table("gamma", "mean", "both", "-", "dispersion", "X", "X", "-")
+d[[8]] <- data.table("mixture", "formula", "string", "x_1 | p_1 + ... + x_n | p_n", "-", "X", "-", "-")
+d[[9]] <- data.table("negBinomial", "mean", "both", "-", "dispersion", "X", "X", "-")
+d[[10]] <- data.table("nonrandom", "formula", "both", "-", "-", "X", "-", "-")
+d[[11]] <- data.table("normal", "mean", "both", "-", "variance", "X", "-", "-")
+d[[12]] <- data.table("noZeroPoisson", "mean", "both", "-", "-", "X", "X", "-")
+d[[13]] <- data.table("poisson", "mean", "both", "-", "-", "X", "X", "-")
+d[[14]] <- data.table("trtAssign", "ratio", "string", "r_1;r_2;...;r_n", "stratification", "X", "X", "-")
+d[[15]] <- data.table("uniform", "range", "string", "from ; to", "-", "X", "-", "-")
+d[[16]] <- data.table("uniformInt", "range", "string", "from ; to", "-", "X", "-", "-")
 
 
 d <- rbindlist(d)
 setnames(d, c("name", "formula", "string/value", "format", "variance", "identity", "log", "logit"))
 knitr::kable(d, align = "lllllccc")
 
+## -----------------------------------------------------------------------------
+def <- defRepeat(nVars = 4, prefix = "g", formula = "1/3;1/3;1/3", 
+   variance = 0, dist = "categorical")
+def <- defData(def, varname = "a", formula = "1;1", dist = "trtAssign")
+def <- defRepeat(def, 3, "b", formula = "5 + a", variance = 3, dist = "normal")
+def <- defData(def, "y", formula = "0.10", dist = "binary")
+
+def
+
 ## -----------------------------------------------------------------------------
 d1 <- defData(varname = "x1", formula = 0, variance = 1, dist = "normal")
 d1 <- defData(d1, varname = "x2", formula = 0.5, dist = "binary")
 
-d2 <- defDataAdd(varname = "y", formula = "-2 + 0.5*x1 + 0.5*x2 + 1*rx", 
+d2 <- defRepeatAdd(nVars = 2, prefix = "q", formula = "5 + 3*rx",
+                   variance = 4, dist = "normal")
+d2 <- defDataAdd(d2, varname = "y", formula = "-2 + 0.5*x1 + 0.5*x2 + 1*rx", 
                  dist = "binary", link = "logit")
 
 dd <- genData(5, d1)
@@ -147,12 +159,12 @@ dd
 ## -----------------------------------------------------------------------------
 d <- defData(varname = "x", formula = 0, variance = 9, dist = "normal")
 
-dc <- defCondition(condition = "x <= -2", formula = "4 + 3*x", variance = 2, 
-                   dist = "normal")
-dc <- defCondition(dc, condition = "x > -2 & x <= 2", formula = "0 + 1*x", variance = 4, 
-                   dist = "normal")
-dc <- defCondition(dc, condition = "x > 2", formula = "-5 + 4*x", variance = 3, 
-                   dist = "normal")
+dc <- defCondition(condition = "x <= -2", formula = "4 + 3*x", 
+                   variance = 2, dist = "normal")
+dc <- defCondition(dc, condition = "x > -2 & x <= 2", formula = "0 + 1*x", 
+                   variance = 4, dist = "normal")
+dc <- defCondition(dc, condition = "x > 2", formula = "-5 + 4*x", 
+                   variance = 3, dist = "normal")
 
 dd <- genData(1000, d)
 dd <- addCondition(dc, dd, newvar = "y")
